@@ -78,6 +78,10 @@ class TeleBot:
     def set_webhook(self, url=None, certificate=None):
         return apihelper.set_webhook(self.token, url, certificate)
 
+    def get_webhook_info(self):
+        result = apihelper.get_webhook_info(self.token)
+        return types.WebhookInfo.de_json(result)
+
     def remove_webhook(self):
         return self.set_webhook()  # No params resets webhook
 
@@ -393,7 +397,8 @@ class TeleBot:
             apihelper.send_photo(self.token, chat_id, photo, caption, reply_to_message_id, reply_markup,
                                  disable_notification))
 
-    def send_audio(self, chat_id, audio, duration=None, performer=None, title=None, reply_to_message_id=None,
+    def send_audio(self, chat_id, audio, caption=None, duration=None, performer=None, title=None,
+                   reply_to_message_id=None,
                    reply_markup=None, disable_notification=None, timeout=None):
         """
         Use this method to send audio files, if you want Telegram clients to display them in the music player. Your audio must be in the .mp3 format.
@@ -407,10 +412,10 @@ class TeleBot:
         :return: Message
         """
         return types.Message.de_json(
-            apihelper.send_audio(self.token, chat_id, audio, duration, performer, title, reply_to_message_id,
+            apihelper.send_audio(self.token, chat_id, audio, caption, duration, performer, title, reply_to_message_id,
                                  reply_markup, disable_notification, timeout))
 
-    def send_voice(self, chat_id, voice, duration=None, reply_to_message_id=None, reply_markup=None,
+    def send_voice(self, chat_id, voice, caption=None, duration=None, reply_to_message_id=None, reply_markup=None,
                    disable_notification=None, timeout=None):
         """
         Use this method to send audio files, if you want Telegram clients to display the file as a playable voice message.
@@ -422,7 +427,7 @@ class TeleBot:
         :return: Message
         """
         return types.Message.de_json(
-            apihelper.send_voice(self.token, chat_id, voice, duration, reply_to_message_id, reply_markup,
+            apihelper.send_voice(self.token, chat_id, voice, caption, duration, reply_to_message_id, reply_markup,
                                  disable_notification, timeout))
 
     def send_document(self, chat_id, data, reply_to_message_id=None, caption=None, reply_markup=None,
@@ -549,8 +554,29 @@ class TeleBot:
             return result
         return types.Message.de_json(result)
 
+    def send_game(self, chat_id, game_short_name, disable_notification=None, reply_to_message_id=None,
+                  reply_markup=None):
+        result = apihelper.send_game(self.token, chat_id, game_short_name, disable_notification, reply_to_message_id,
+                                     reply_markup)
+        return types.Message.de_json(result)
+
+    def set_game_score(self, user_id, score, chat_id=None, message_id=None, inline_message_id=None, edit_message=None):
+        result = apihelper.set_game_score(self.token, user_id, score, chat_id, message_id, inline_message_id,
+                                          edit_message)
+        if type(result) == bool:
+            return result
+        return types.Message.de_json(result)
+
+    def get_game_high_scores(self, user_id, chat_id=None, message_id=None, inline_message_id=None):
+        result = apihelper.get_game_high_scores(self.token, user_id, chat_id, message_id, inline_message_id)
+        ret = []
+        for r in result:
+            ret.append(types.GameHighScore.de_json(r))
+        return ret
+
     def edit_message_caption(self, caption, chat_id=None, message_id=None, inline_message_id=None, reply_markup=None):
-        result = apihelper.edit_message_caption(self.token, caption, chat_id, message_id, inline_message_id, reply_markup)
+        result = apihelper.edit_message_caption(self.token, caption, chat_id, message_id, inline_message_id,
+                                                reply_markup)
         if type(result) == bool:
             return result
         return types.Message.de_json(result)
@@ -579,7 +605,7 @@ class TeleBot:
         return apihelper.answer_inline_query(self.token, inline_query_id, results, cache_time, is_personal, next_offset,
                                              switch_pm_text, switch_pm_parameter)
 
-    def answer_callback_query(self, callback_query_id, text=None, show_alert=None):
+    def answer_callback_query(self, callback_query_id, text=None, show_alert=None, url=None):
         """
         Use this method to send answers to callback queries sent from inline keyboards. The answer will be displayed to
         the user as a notification at the top of the chat screen or as an alert.
@@ -588,7 +614,7 @@ class TeleBot:
         :param show_alert:
         :return:
         """
-        return apihelper.answer_callback_query(self.token, callback_query_id, text, show_alert)
+        return apihelper.answer_callback_query(self.token, callback_query_id, text, show_alert, url)
 
     def register_for_reply(self, message, callback):
         """
@@ -748,6 +774,7 @@ class TeleBot:
         def decorator(handler):
             handler_dict = self._build_handler_dict(handler, func=func, **kwargs)
             self.add_callback_query_handler(handler_dict)
+            return handler
 
         return decorator
 
