@@ -127,6 +127,12 @@ def set_webhook(token, url=None, certificate=None):
     return _make_request(token, method_url, params=payload, files=files)
 
 
+def get_webhook_info(token):
+    method_url = r'getWebhookInfo'
+    payload = {}
+    return _make_request(token, method_url, params=payload)
+
+
 def get_updates(token, offset=None, limit=None, timeout=None):
     method_url = r'getUpdates'
     payload = {}
@@ -280,7 +286,7 @@ def send_video(token, chat_id, data, duration=None, caption=None, reply_to_messa
     return _make_request(token, method_url, params=payload, files=files, method='post')
 
 
-def send_voice(token, chat_id, voice, duration=None, reply_to_message_id=None, reply_markup=None,
+def send_voice(token, chat_id, voice, caption=None, duration=None, reply_to_message_id=None, reply_markup=None,
                disable_notification=None, timeout=None):
     method_url = r'sendVoice'
     payload = {'chat_id': chat_id}
@@ -289,6 +295,8 @@ def send_voice(token, chat_id, voice, duration=None, reply_to_message_id=None, r
         files = {'voice': voice}
     else:
         payload['voice'] = voice
+    if caption:
+        payload['caption'] = caption
     if duration:
         payload['duration'] = duration
     if reply_to_message_id:
@@ -302,7 +310,7 @@ def send_voice(token, chat_id, voice, duration=None, reply_to_message_id=None, r
     return _make_request(token, method_url, params=payload, files=files, method='post')
 
 
-def send_audio(token, chat_id, audio, duration=None, performer=None, title=None, reply_to_message_id=None,
+def send_audio(token, chat_id, audio, caption=None, duration=None, performer=None, title=None, reply_to_message_id=None,
                reply_markup=None, disable_notification=None, timeout=None):
     method_url = r'sendAudio'
     payload = {'chat_id': chat_id}
@@ -311,6 +319,8 @@ def send_audio(token, chat_id, audio, duration=None, performer=None, title=None,
         files = {'audio': audio}
     else:
         payload['audio'] = audio
+    if caption:
+        payload['caption'] = caption
     if duration:
         payload['duration'] = duration
     if performer:
@@ -418,15 +428,80 @@ def edit_message_reply_markup(token, chat_id=None, message_id=None, inline_messa
     return _make_request(token, method_url, params=payload)
 
 
+# Game
+
+def send_game(token, chat_id, game_short_name, disable_notification=None, reply_to_message_id=None, reply_markup=None):
+    method_url = r'sendGame'
+    payload = {'chat_id': chat_id, 'game_short_name': game_short_name}
+    if disable_notification:
+        payload['disable_notification'] = disable_notification
+    if reply_to_message_id:
+        payload['reply_to_message_id'] = reply_to_message_id
+    if reply_markup:
+        payload['reply_markup'] = _convert_markup(reply_markup)
+    return _make_request(token, method_url, params=payload)
+
+
+# https://core.telegram.org/bots/api#setgamescore
+def set_game_score(token, user_id, score, chat_id=None, message_id=None, inline_message_id=None, edit_message=None):
+    """
+    Use this method to set the score of the specified user in a game. On success, if the message was sent by the bot, returns the edited Message, otherwise returns True. Returns an error, if the new score is not greater than the user's current score in the chat.
+    :param token: Bot's token (you don't need to fill this)
+    :param user_id: User identifier
+    :param score: New score, must be positive
+    :param chat_id: (Optional, required if inline_message_id is not specified) Unique identifier for the target chat (or username of the target channel in the format @channelusername)
+    :param message_id: (Optional, required if inline_message_id is not specified) Unique identifier of the sent message
+    :param inline_message_id: (Optional, required if chat_id and message_id are not specified) Identifier of the inline message
+    :param edit_message: (Optional) Pass True, if the game message should be automatically edited to include the current scoreboard
+    :return:
+    """
+    method_url = r'setGameScore'
+    payload = {'user_id': user_id, 'score': score}
+    if chat_id:
+        payload['chat_id'] = chat_id
+    if message_id:
+        payload['message_id'] = message_id
+    if inline_message_id:
+        payload['inline_message_id'] = inline_message_id
+    if edit_message:
+        payload['edit_message'] = edit_message
+    return _make_request(token, method_url, params=payload)
+
+
+# https://core.telegram.org/bots/api#getgamehighscores
+def get_game_high_scores(token, user_id, chat_id=None, message_id=None, inline_message_id=None):
+    """
+    Use this method to get data for high score tables. Will return the score of the specified user and several of his neighbors in a game. On success, returns an Array of GameHighScore objects.
+    This method will currently return scores for the target user, plus two of his closest neighbors on each side. Will also return the top three users if the user and his neighbors are not among them. Please note that this behavior is subject to change.
+    :param token: Bot's token (you don't need to fill this)
+    :param user_id: Target user id
+    :param chat_id: (Optional, required if inline_message_id is not specified) Unique identifier for the target chat (or username of the target channel in the format @channelusername)
+    :param message_id: (Optional, required if inline_message_id is not specified) Unique identifier of the sent message
+    :param inline_message_id: (Optional, required if chat_id and message_id are not specified) Identifier of the inline message
+    :return:
+    """
+    method_url = r'getGameHighScores'
+    payload = {'user_id': user_id}
+    if chat_id:
+        payload['chat_id'] = chat_id
+    if message_id:
+        payload['message_id'] = message_id
+    if inline_message_id:
+        payload['inline_message_id'] = inline_message_id
+    return _make_request(token, method_url, params=payload)
+
+
 # InlineQuery
 
-def answer_callback_query(token, callback_query_id, text=None, show_alert=None):
+def answer_callback_query(token, callback_query_id, text=None, show_alert=None, url=None):
     method_url = 'answerCallbackQuery'
     payload = {'callback_query_id': callback_query_id}
     if text:
         payload['text'] = text
     if show_alert:
         payload['show_alert'] = show_alert
+    if url:
+        payload['url'] = url
     return _make_request(token, method_url, params=payload, method='post')
 
 
